import { getModelForClass, getClass } from '@typegoose/typegoose';
import { AnyParamConstructor } from '@typegoose/typegoose/lib/types';
import { upperFirst } from 'lodash';
import { ServiceError } from '../error/CustomerError.error';
import { ErrorCode } from '../error/Codes';
/**
 * 根据表名返回model
 * @param modelName 表名
 * @returns model
 */
export function GetModel(modelName) {
  let model;
  try {
    model = getModelForClass(
      getClass(upperFirst(modelName)) as AnyParamConstructor<any>
    );
  } catch (error) {
    console.error(error);
    throw new ServiceError(
      ErrorCode.SERVICE_FAULT(`${modelName}-生成模型错误`)
    );
  }
  if (!model) {
    throw new ServiceError(ErrorCode.SERVICE_FAULT(`${modelName}-未找到模型`));
  }

  return model;
}
/**
 * 生成随机字符串
 * @param len 位数,默认6位
 */
export const randomStr = (len = 6) => {
  return Math.random().toString(36).slice(-len);
};
